certs-mail-import
===================
Fetatures
___________
    -  Aplikace v PyQT
    -  Import osobního certifikátu ve formátu p12 do Thunderbirda (dále emailový klient)
        - Možnost rozšíření o dalšího klienta
    -  Import certifikační autority do emailového klienta
    -  Import osobních certifikátů do emailového klienta
        - Z místní složky
        - Z webové složky
    -  Fungování na Linuxu i Windows
    -  Vytvoření p12 certifikátu ze soukromého a veřejného klíče
    -  Vytvoření žádosti a klíče
    -  Jednoduchá aplikace použitelná i netechnickým uživatelem včetně instalace

